import time

# Import the preset TestFixture.
from .Frames_trasnmission_fixture import FixtureFramesTrasnmission, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestCanTransmitter(FixtureFramesTrasnmission):

    # This method will be executed just before
    # the test case core method execution.
    def setUp(self):
        logger.info("Setup test case")

    # This method will be executed just after
    # the test case method execution.
    def tearDown(self):
        logger.info("Tear down test case")

    # Create the test case method that holds the main test steps.
    def test_can_transmitter(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual in vehicle communication.
        channel_name = 'B1_CAN'
        frame_id = 21  # 0x15 in hexadecimal
        payload = [0x1, 0x2, 0x3, 0x48]

        can_ch = ChannelFactory().get_can_channel(channel_name, False)

        # Retrieves the desired can frame object associated with the the frame_id.
        can_fr = can_ch.get_frame(frame_id)

        # Log any useful message.
        logger.info("Transmit a can frame")

        # Transmit the can frame.
        can_transmit = can_fr.transmitter.transmit_frame(payload)

        time.sleep(2)

        # Confirm the correct transmission by verifying
        # the boolean return value of transmit_frame().
        # If there are no issues during transmission,
        # the return value should be true.
        self.assertTrue(can_transmit, Severity.BLOCKER,
                        "Error when sending a can fd message")
